@@ -59,7 +59,7 @@ def delete_obsolete(lexicon):
         "_words.txt",
         "_links.tsv",
     ]:
-        file = mer_path + "/data/" + lexicon + ending
+        file = mer_path + "data/" + lexicon + ending
         with open(file, "r+") as f:
             new_f = f.readlines()
             f.seek(0)
@@ -89,7 +89,7 @@ def delete_entity_by_uri(entity_uri, lexicon):
     if isinstance(entity_uri, str):
         entity_uri = [entity_uri] 
     # remove from links and save entity labels
-    with open(mer_path + "/data/" + lexicon + "_links.tsv", "r+") as f:
+    with open(mer_path + "data/" + lexicon + "_links.tsv", "r+") as f:
         new_f = f.readlines()
         f.seek(0)
         for line in new_f:
@@ -132,7 +132,7 @@ def delete_entity(entity_text, lexicon):
     ['5', '11', 'silver', 'https://raw.githubusercontent.com/lasigeBioTM/ssm/master/metals.owl#silver']]
 
     """
-    basepath = mer_path + "/data/" + lexicon
+    basepath = mer_path + "data/" + lexicon
     if isinstance(entity_text, str):
         entity_text = [entity_text]
     entities_per_file = {"{}_word1.txt".format(basepath):[],
@@ -191,24 +191,24 @@ def merge_processed_lexicons(lexicon_list, new_name):
     """
     check_gawk()
     # cwd = os.getcwd()
-    # os.chdir(mer_path + "/data/")
+    # os.chdir(mer_path + "data/")
     # merge by file type
     if "_" in new_name:
         new_name = new_name.replace("_", "")
         print("renamed to ", new_name)
     lexicon_files = []
     for l in lexicon_list:
-        lexicon_files += glob.glob(mer_path + "/data/" + l + "_*.txt")
-        lexicon_files += glob.glob(mer_path + "/data/" + l + ".txt")
-        lexicon_files += glob.glob(mer_path + "/data/" + l + "_links.tsv")
+        lexicon_files += glob.glob(mer_path + "data/" + l + "_*.txt")
+        lexicon_files += glob.glob(mer_path + "data/" + l + ".txt")
+        lexicon_files += glob.glob(mer_path + "data/" + l + "_links.tsv")
 
-    with open(mer_path + "/data/" + new_name + ".txt", "w") as outfile:
+    with open(mer_path + "data/" + new_name + ".txt", "w") as outfile:
         for fname in lexicon_files:
             if fname.endswith(".txt") and "_word" not in fname:
                 with open(fname) as infile:
                     outfile.write(infile.read())
 
-    with open(mer_path + "/data/" + new_name + "_links.tsv", "w") as outfile:
+    with open(mer_path + "data/" + new_name + "_links.tsv", "w") as outfile:
         for fname in lexicon_files:
             if fname.endswith("_links.tsv"):
                 with open(fname) as infile:
@@ -216,7 +216,7 @@ def merge_processed_lexicons(lexicon_list, new_name):
 
     for ftype in ["word1", "word2", "words", "words2"]:
         with open(
-            mer_path + "/data/" + new_name + "_{}.txt".format(ftype), "w"
+            mer_path + "data/" + new_name + "_{}.txt".format(ftype), "w"
         ) as outfile:
             for fname in lexicon_files:
                 if fname.endswith("_{}.txt".format(ftype)):
@@ -250,7 +250,7 @@ def process_lexicon(lexicon, ltype="txt"):
     """
     check_gawk()
     cwd = os.getcwd()
-    os.chdir(mer_path + "/data/")
+    os.chdir(mer_path + "data/")
     if sys.version_info[0] == 3 and sys.version_info[1] > 5:
         session = Popen(
             ["../produce_data_files.sh", lexicon + "." + ltype],
@@ -288,13 +288,14 @@ def get_entities_mp(documents, lexicon, n_cores=4):
 
 
     :Examples:
-        >>> import merpy
-        >>> merpy.download_lexicons()
-        >>> doc_text = 'Influenza, commonly known as "the flu", is an infectious disease caused by an influenza virus. Symptoms can be mild to severe. The most common symptoms include: a high fever, runny nose, sore throat, muscle pains, headache, coughing, and feeling tired'
-        >>> docs = {i:doc_text for i in range(10)}
-        >>> entities = merpy.get_entities_mp(docs, "hp")
-        >>> print(len(entities))
-        10
+
+    >>> import merpy
+    >>> merpy.download_lexicons()
+    >>> doc_text = 'Influenza, commonly known as "the flu", is an infectious disease caused by an influenza virus. Symptoms can be mild to severe. The most common symptoms include: a high fever, runny nose, sore throat, muscle pains, headache, coughing, and feeling tired'
+    >>> docs = {i:doc_text for i in range(10)}
+    >>> entities = merpy.get_entities_mp(docs, "hp")
+    >>> print(len(entities))
+    10
 
     """
     docs = [documents[d] for d in range(len(documents))]
@@ -317,13 +318,13 @@ def get_entities(text, lexicon):
 
     :Example:
 
-        >>> import merpy
-        >>> merpy.download_lexicons()
-        >>> document = 'Influenza, commonly known as "the flu", is an infectious disease caused by an influenza virus. Symptoms can be mild to severe. The most common symptoms include: a high fever, runny nose, sore throat, muscle pains, headache, coughing, and feeling tired'
-        >>> merpy.get_entities(document, "hp")
-        [['111', '115', 'mild', 'http://purl.obolibrary.org/obo/HP_0012825'], \
-['200', '206', 'muscle', 'http://purl.obolibrary.org/obo/UBERON_0005090'], \
-['246', '251', 'tired', 'http://purl.obolibrary.org/obo/HP_0012378']]
+    >>> import merpy
+    >>> merpy.download_lexicons()
+    >>> document = 'Influenza, commonly known as "the flu", is an infectious disease caused by an influenza virus. Symptoms can be mild to severe. The most common symptoms include: a high fever, runny nose, sore throat, muscle pains, headache, coughing, and feeling tired'
+    >>> merpy.get_entities(document, "hp")
+    [['111', '115', 'mild', 'http://purl.obolibrary.org/obo/HP_0012825'], \
+    ['200', '206', 'muscle', 'http://purl.obolibrary.org/obo/UBERON_0005090'], \
+    ['246', '251', 'tired', 'http://purl.obolibrary.org/obo/HP_0012378']]
     
     """
     check_gawk()
@@ -357,8 +358,9 @@ def download_mer():
     """Download latest version of MER from GitHub.
 
     :Example:
-        >>> import merpy
-        >>> merpy.download_mer()
+
+    >>> import merpy
+    >>> merpy.download_mer()
     
     """
     download_link = "https://github.com/lasigeBioTM/MER/archive/master.zip"
@@ -371,28 +373,27 @@ def download_mer():
 
     bash_scripts = ["get_entities.sh", "get_similarity.sh", "produce_data_files.sh"]
     for script_name in bash_scripts:
-        shutil.move("MER-master/" + script_name, mer_path + "/" + script_name)
-        os.chmod(mer_path + "/" + script_name, stat.S_IRWXU)
+        shutil.move("MER-master/" + script_name, mer_path + script_name)
+        os.chmod(mer_path + script_name, stat.S_IRWXU)
 
     # clean up
     os.remove(file_name)
     shutil.rmtree("MER-master/")
 
 
-def download_lexicons(
-    download_link="http://labs.rd.ciencias.ulisboa.pt/mer/data/lexicons202103.tgz"
-):
+def download_lexicons(download_link="http://labs.rd.ciencias.ulisboa.pt/mer/data/lexicons202103.tgz"):
     """Download preprocessed lexicons
 
     :param link: link with tar file containing preprocessed lexicons
     :type link: string
 
     :Example:
-        >>> import merpy
-        >>> merpy.download_lexicons()
-        >>> document = 'Influenza, commonly known as "the flu", is an infectious disease caused by an influenza virus. Symptoms can be mild to severe. The most common symptoms include: a high fever, runny nose, sore throat, muscle pains, headache, coughing, and feeling tired'
-        >>> merpy.get_entities(document, "hp")
-        [['111', '115', 'mild', 'http://purl.obolibrary.org/obo/HP_0012825'], \
+
+    >>> import merpy
+    >>> merpy.download_lexicons()
+    >>> document = 'Influenza, commonly known as "the flu", is an infectious disease caused by an influenza virus. Symptoms can be mild to severe. The most common symptoms include: a high fever, runny nose, sore throat, muscle pains, headache, coughing, and feeling tired'
+    >>> merpy.get_entities(document, "hp")
+    [['111', '115', 'mild', 'http://purl.obolibrary.org/obo/HP_0012825'], \
 ['200', '206', 'muscle', 'http://purl.obolibrary.org/obo/UBERON_0005090'], \
 ['246', '251', 'tired', 'http://purl.obolibrary.org/obo/HP_0012378']]
 
@@ -420,51 +421,56 @@ def create_lexicon(entities, name):
     :type name: string
 
     :Example:
-        >>> import merpy
-        >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelist")
-        wrote genelist lexicon
-        >>> merpy.process_lexicon("genelist")
-        >>> merpy.get_entities("gene1 and gene2", "genelist")
-        [['0', '5', 'gene1'], ['10', '15', 'gene2']]
+
+    >>> import merpy
+    >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelist")
+    wrote genelist lexicon
+    >>> merpy.process_lexicon("genelist")
+    >>> merpy.get_entities("gene1 and gene2", "genelist")
+    [['0', '5', 'gene1'], ['10', '15', 'gene2']]
 
     """
     if "_" in name:
         name = name.replace("_", "")
         print("renamed to ", name)
-    with open(mer_path + "/data/" + name + ".txt", "w", encoding="utf8") as f:
+    with open(mer_path + "data/" + name + ".txt", "w", encoding="utf8") as f:
         f.write("\n".join(entities))
     print("wrote {} lexicon".format(name))
 
 
 def create_lexicon_from_file(filename, name, links_file=None):
-    """Create a lexicon based on an existing file
-    The file is simply copied to the datadir
+    """Create a lexicon based on an existing file.
+    The file is simply copied to the datadir. 
+
 
     :param filename: file with list of entities
     :type entities: string
     :param name: name of lexicon
     :type name: string
-    :param links_file: path to links file or None
+    :param links_file: path to links file or None (labels must be in lowercase)
     :type links_file: string
 
     :Example:
-        >>> import merpy
-        >>> with open("genelist", 'w') as f:
-        ...     f.write("\\n".join(["gene1", "gene2", "gene3"])) #doctest: +SKIP
-        >>> merpy.create_lexicon_from_file("genelist", "genelist")
-        copied genelist lexicon
-        >>> merpy.process_lexicon("genelist")
-        >>> merpy.get_entities("gene1 and gene2", "genelist")
-        [['0', '5', 'gene1'], ['10', '15', 'gene2']]
+
+    >>> import merpy
+    >>> with open("genelist", 'w') as f:
+    ...  f.write("\\n".join(["Gene1", "Gene2", "Gene3"]))
+    >>> with open("genelist_links", 'w') as g:
+    ...  g.write("\\n".join(["gene1\\tID1", "gene2\\tID2", "gene3\\tID3"]))
+    >>> merpy.create_lexicon_from_file("genelist", "genelist", "genelist_links")
+    copied genelist lexicon
+    >>> merpy.process_lexicon("genelist")
+    >>> merpy.get_entities("gene1 and gene2", "genelist")
+    [['0', '5', 'gene1', 'ID1'], ['10', '15', 'gene2', 'ID2']]
     """
 
     check_gawk()
     if "_" in name:
         name = name.replace("_", "")
         print("renamed to ", name)
-    shutil.copyfile(filename, mer_path + "/data/" + name + ".txt")
+    shutil.copyfile(filename, mer_path + "data/" + name + ".txt")
     if links_file is not None:
-        shutil.copyfile(links_file, mer_path + "/data/" + name + "_links.tsv")
+        shutil.copyfile(links_file, mer_path + "data/" + name + "_links.tsv")
     print("copied {} lexicon".format(name))
 
 
@@ -477,18 +483,19 @@ def delete_lexicon(name, delete_lexicon=False):
     :type name: Boolean
 
     :Example:
-        >>> import merpy
-        >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelist")
-        wrote genelist lexicon
-        >>> merpy.delete_lexicon("genelist")
-        deleted genelist lexicon
+
+    >>> import merpy
+    >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelist")
+    wrote genelist lexicon
+    >>> merpy.delete_lexicon("genelist")
+    deleted genelist lexicon
     """
 
-    for filename in glob.glob(mer_path + "/data/" + name + "_*"):
+    for filename in glob.glob(mer_path + "data/" + name + "_*"):
         os.remove(filename)
 
     if delete_lexicon:
-        for filename in glob.glob(mer_path + "/data/" + name + ".*"):
+        for filename in glob.glob(mer_path + "data/" + name + ".*"):
             os.remove(filename)
     print("deleted {} lexicon".format(name))
 
@@ -502,27 +509,28 @@ def rename_lexicon(name, new_name):
     :type name: string
 
     :Example:
-        >>> import merpy
-        >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelist")
-        wrote genelist lexicon
-        >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelists")
-        wrote genelists lexicon
-        >>> merpy.rename_lexicon("genelist", "genes")
-        renamed genelist lexicon to genes
-        >>> "genelists" in merpy.get_lexicons()[0]
-        True
-        >>> "genelist" not in merpy.get_lexicons()[0]
-        True
-        >>> "genes" in merpy.get_lexicons()[0]
-        True
+
+    >>> import merpy
+    >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelist")
+    wrote genelist lexicon
+    >>> merpy.create_lexicon(["gene1", "gene2", "gene3"], "genelists")
+    wrote genelists lexicon
+    >>> merpy.rename_lexicon("genelist", "genes")
+    renamed genelist lexicon to genes
+    >>> "genelists" in merpy.get_lexicons()[0]
+    True
+    >>> "genelist" not in merpy.get_lexicons()[0]
+    True
+    >>> "genes" in merpy.get_lexicons()[0]
+    True
     """
     if "_" in new_name:
         new_name = name.replace("_", "")
         print("renamed to ", new_name)
 
-    for filename in glob.glob(mer_path + "/data/" + name + "_*"):
+    for filename in glob.glob(mer_path + "data/" + name + "_*"):
         os.rename(filename, filename.replace(name, new_name))
-    for filename in glob.glob(mer_path + "/data/" + name + ".*"):
+    for filename in glob.glob(mer_path + "data/" + name + ".*"):
         os.rename(filename, filename.replace(name, new_name))
     print("renamed {} lexicon to {}".format(name, new_name))
 
@@ -538,18 +546,19 @@ def create_mappings(mapped_entities, name):
     :type name: string
 
     :Example:
-        >>> import merpy
-        >>> mappings = {"gold": 1, "silver": 2, "metal": [3,4]}
-        >>> create_lexicon(mappings.keys(), "metals")
-        wrote metals lexicon
-        >>> create_mappings(mappings, "metals")
-        wrote metals mappings
-        >>> merpy.process_lexicon("metals")
-        >>> merpy.get_entities("gold and silver are metals", "metals")
-        [['0', '4', 'gold', '1'], ['9', '15', 'silver', '2']]
+
+    >>> import merpy
+    >>> mappings = {"gold": 1, "silver": 2, "metal": [3,4]}
+    >>> create_lexicon(mappings.keys(), "metals")
+    wrote metals lexicon
+    >>> create_mappings(mappings, "metals")
+    wrote metals mappings
+    >>> merpy.process_lexicon("metals")
+    >>> merpy.get_entities("gold and silver are metals", "metals")
+    [['0', '4', 'gold', '1'], ['9', '15', 'silver', '2']]
     """
     with open(
-        mer_path + "/data/" + name + "_links.tsv", "w", encoding="utf8"
+        mer_path + "data/" + name + "_links.tsv", "w", encoding="utf8"
     ) as links_file:
         for e in mapped_entities:
             if type(mapped_entities[e]) is list:
@@ -571,30 +580,31 @@ def download_lexicon(url, name, ltype="txt"):
     :param format: format of lexicon file (txt, owl or rdf)
 
     :Example:
-        >>> import merpy
-        >>> merpy.download_lexicon("https://github.com/lasigeBioTM/MER/raw/biocreative2017/data/ChEBI.txt", "chebi_txt", 'txt')
-        wrote chebi_txt lexicon
-        >>> merpy.process_lexicon("chebi_txt", "txt")
-        >>> merpy.get_entities("caffeine", "chebi_txt")
-        [['0', '8', 'caffeine']]
-        >>> merpy.download_lexicon("ftp://ftp.ebi.ac.uk/pub/databases/chebi/ontology/chebi_lite.owl", 'chebi_lite', 'owl')
-        wrote chebi_lite lexicon
-        >>> merpy.process_lexicon("chebi_lite", "owl")
-        >>> merpy.get_entities("caffeine", "chebi_lite")
-        [['0', '8', 'caffeine', 'http://purl.obolibrary.org/obo/CHEBI_27732']]
+
+    >>> import merpy
+    >>> merpy.download_lexicon("https://github.com/lasigeBioTM/MER/raw/biocreative2017/data/ChEBI.txt", "chebi_txt", 'txt')
+    wrote chebi_txt lexicon
+    >>> merpy.process_lexicon("chebi_txt", "txt")
+    >>> merpy.get_entities("caffeine", "chebi_txt")
+    [['0', '8', 'caffeine']]
+    >>> merpy.download_lexicon("http://purl.obolibrary.org/obo/chebi/chebi_lite.owl", 'chebi_lite', 'owl')
+    wrote chebi_lite lexicon
+    >>> merpy.process_lexicon("chebi_lite", "owl")
+    >>> merpy.get_entities("caffeine", "chebi_lite")
+    [['0', '8', 'caffeine', 'http://purl.obolibrary.org/obo/CHEBI_27732']]
 
     """
     # if url.startswith("http"):
     #     r = requests.get(url)
-    #     with open(mer_path + "/data/" + name + "." + ltype, "wb") as f:
+    #     with open(mer_path + "data/" + name + "." + ltype, "wb") as f:
     #         f.write(r.content)
     # elif url.startswith("ftp"):
     #     r = urllib.request.urlopen(url)
 
-    #     with open(mer_path + "/data/" + name + "." + ltype, "wb") as f:
+    #     with open(mer_path + "data/" + name + "." + ltype, "wb") as f:
     #         shutil.copyfileobj(r, f)
 
-    file_name = mer_path + "/data/" + name + "." + ltype
+    file_name = mer_path + "data/" + name + "." + ltype
     with urllib.request.urlopen(url) as response, open(file_name, 'wb') as out_file:
         data = response.read() # a `bytes` object
         out_file.write(data)
@@ -610,13 +620,14 @@ def get_lexicons():
     :rtype: list
 
     :Example:
-        >>> import merpy
-        >>> merpy.get_lexicons() # doctest: +ELLIPSIS
-        ([...], [...], [...])
+
+    >>> import merpy
+    >>> merpy.get_lexicons() # doctest: +ELLIPSIS
+    ([...], [...], [...])
 
     """
     all_lexicons, loaded_lexicons, links_lexicons = [], [], []
-    files = os.listdir(mer_path + "/data/")
+    files = os.listdir(mer_path + "data/")
 
     for f in files:
         if f.endswith(".txt") and not (
@@ -642,16 +653,17 @@ def show_lexicons():
     """Print lexicon list
 
     :Example:
-        >>> import merpy
-        >>> merpy.show_lexicons() # doctest: +ELLIPSIS
-        lexicons preloaded:
-        [...]
-        <BLANKLINE>
-        lexicons loaded ready to use:
-        [...]
-        <BLANKLINE>
-        lexicons with linked concepts:
-        [...]
+
+    >>> import merpy
+    >>> merpy.show_lexicons() # doctest: +ELLIPSIS
+    lexicons preloaded:
+    [...]
+    <BLANKLINE>
+    lexicons loaded ready to use:
+    [...]
+    <BLANKLINE>
+    lexicons with linked concepts:
+    [...]
 
     """
     lexicons = get_lexicons()
@@ -680,13 +692,13 @@ def get_similarities(entities, database):
 
     :Example:
 
-        >>> import merpy
-        >>> import ssmpy 
-        >>> merpy.process_lexicon("lexicon")
-        >>> document = "α-maltose and nicotinic acid was found, but not nicotinic acid D-ribonucleotide"
-        >>> entities = merpy.get_entities(document, "lexicon") 
-        >>> merpy.get_similarities(entities, 'chebi.db')
-        [['0', '9', 'α-maltose', 'http://purl.obolibrary.org/obo/CHEBI_18167', 0.02834388514184269], ['14', '28', 'nicotinic acid', 'http://purl.obolibrary.org/obo/CHEBI_15940', 0.07402224403263755], ['48', '62', 'nicotinic acid', 'http://purl.obolibrary.org/obo/CHEBI_15940', 0.07402224403263755], ['48', '79', 'nicotinic acid D-ribonucleotide', 'http://purl.obolibrary.org/obo/CHEBI_15763', 0.07402224403263755]]
+    >>> import merpy
+    >>> import ssmpy 
+    >>> merpy.process_lexicon("lexicon")
+    >>> document = "α-maltose and nicotinic acid was found, but not nicotinic acid D-ribonucleotide"
+    >>> entities = merpy.get_entities(document, "lexicon") 
+    >>> merpy.get_similarities(entities, 'chebi.db')
+    [['0', '9', 'α-maltose', 'http://purl.obolibrary.org/obo/CHEBI_18167', 0.02834388514184269], ['14', '28', 'nicotinic acid', 'http://purl.obolibrary.org/obo/CHEBI_15940', 0.07402224403263755], ['48', '62', 'nicotinic acid', 'http://purl.obolibrary.org/obo/CHEBI_15940', 0.07402224403263755], ['48', '79', 'nicotinic acid D-ribonucleotide', 'http://purl.obolibrary.org/obo/CHEBI_15763', 0.07402224403263755]]
 
     """
     ssmpy.semantic_base(database)
